************
Contributing
************

If you want to contribute to the project and make it better, your help is very welcome.

Submitting an issue
~~~~~~~~~~~~~~~~~~~
Please submit an issue if you want to report a bug or propose new features.

Generating documentation
~~~~~~~~~~~~~~~~~~~~~~~~
Please add documentation to your code by using *Docstrings*. Here is an example:

    .. code:: python

        """Foo module for showing documentation example."""

        class Foo:
            """Docstring for class Foo.

            This should be a description of the Foo class.
            It's common for programmers to give a code example inside of their
            docstring::

                from tasho import Foo
                robot = Foo()

            Here is a link to :py:meth:`__init__`.
            """


            def __init__(self, arg1 = None, arg2 = None):
                """Start the Foo.

                :param arg1: description
                :param arg2: description
                :type arg1: type description
                :type arg1: type description
                :return: return description
                :rtype: the return type description

                """

                return arg1

Documentation is automatically generated by GitLab CI/CD when a commit is pushed to the repository.  

However, if you want to generate it offline, you may go to the `docs` directory and execute `make html` from there.  
This will generate a `build/html` directory with the generated documentation.

This built documentation won't be uploaded to the repository with any commit, since it is being ignored by git, and it should keep like that.
